import React from 'react';
import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
import { Text } from 'react-native';
import { createStackNavigator } from '@react-navigation/stack';
import { InformacionSabiasQue } from './InformacionSabiasQue';
import { ValorPagar } from './ValorPagar';
import { VistaPreviaValoPagar } from './VistaPreviaValoPagar';
import { ConfirmarTransaccion } from './ConfirmarTransaccion';
import { NavigationContainer } from '@react-navigation/native';
import  Icon  from 'react-native-vector-icons/FontAwesome';
import { RouteCamaraQr } from './componetsQr/RouteCamara';

export interface IconoPropiedades {
  label: string;
  name: string;
  color?: string;
  size?: number;
}
export interface ComponenteIcono {
  name: string;
  component: React.FC;
  icono?: IconoPropiedades;
  prop?: object;
}
export type Props = {
  componentes: ComponenteIcono[];
};
export function NavigationContainerS({ componentes }: any): JSX.Element {
return(
    <NavigationContainer>
      {componentes}
    </NavigationContainer>
)
}
export function DeUnaNavigate({ componentes }: Props): JSX.Element {
  const Stack = createStackNavigator();
  return (
      <Stack.Navigator
        initialRouteName="Tabs"
        screenOptions={{
          headerShown: false,
        }}
      >
        <Stack.Screen name="Prueba">
          {() => (
            <>
              <Text>SEE</Text>
            </>
          )}
        </Stack.Screen>
        <Stack.Screen name="Tabs">
          {() => {
            return <TabNavigation componentes={componentes} />;
          }}
        </Stack.Screen>
        <Stack.Screen name="InformacionCard">
          {() => {
            return <InformacionSabiasQue />;
          }}
        </Stack.Screen>
        <Stack.Screen name="PayRecibe">{() => <ValorPagar />}</Stack.Screen>
        <Stack.Screen name="Confirmacion">
          {() => <VistaPreviaValoPagar />}
        </Stack.Screen>
        <Stack.Screen name="ConfirmarTransaccion">
          {() => <ConfirmarTransaccion />}
        </Stack.Screen>
        <Stack.Screen name="CamaraQrNavigate">
          {() => <RouteCamaraQr />}
        </Stack.Screen>
      </Stack.Navigator>
  );
}
export const TabNavigation = ({ componentes }: Props) => {
  const Tab = createBottomTabNavigator();
  
  return (
    <Tab.Navigator
      screenOptions={{
        headerShown: false,
      }}
    >
      {componentes &&
        componentes.map((item: ComponenteIcono) => (
          <Tab.Screen
            key={item.name}
            name={item.name}
            options={{
              tabBarLabel: item.icono!.label,
              tabBarIcon: ({ color, size }) => (
                <Icon name={item.icono!.name} size={size} color={color} />
              )
             
            }}
          >
            {() => <item.component {...item.prop} />}
          </Tab.Screen>
        ))}
    </Tab.Navigator>
  );
};
